@@ -5,13 +5,14 @@ Module defining different sampler interfaces.
 import logging
 
 from scisample.base_sampler import BaseSampler
-from scisample.best_candidate import BestCandidateSampler
-from scisample.column_list import ColumnListSampler
-from scisample.cross_product import CrossProductSampler
-from scisample.csv import CsvSampler
-from scisample.custom import CustomSampler
-from scisample.list import ListSampler
-from scisample.random import RandomSampler
+from scisample.best_candidate_sampler import BestCandidateSampler
+from scisample.column_list_sampler import ColumnListSampler
+from scisample.cross_product_sampler import CrossProductSampler
+from scisample.csv_sampler import CsvSampler
+from scisample.custom_sampler import CustomSampler
+from scisample.list_sampler import ListSampler
+from scisample.random_sampler import RandomSampler
+from scisample.uqpipeline_sampler import UQPipelineSampler
 from scisample.utils import SamplingError, log_and_raise_exception
 
 LOG = logging.getLogger(__name__)
@@ -23,7 +24,8 @@ BaseSampler.SAMPLE_FUNCTIONS_DICT = {
     'cross_product': CrossProductSampler,
     'csv': CsvSampler,
     'random': RandomSampler,
-    'custom': CustomSampler
+    'custom': CustomSampler,
+    'uqpipeline': UQPipelineSampler,
 }
 
 BaseSampler.SAMPLE_FUNCTIONS_KEYS = BaseSampler.SAMPLE_FUNCTIONS_DICT.keys()
